@@ -1,5 +1,5 @@
 // Copyright (C) 2018 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "coreprotocol.h"
 #include "datadevice.h"
@@ -77,8 +77,10 @@ void Surface::surface_attach(Resource *resource, wl_resource *buffer, int32_t x,
             m_image = QImage();
     } else {
         QPoint offset(x, y);
+        if (resource->version() < 5)
+            m_pending.commitSpecific.attachOffset = offset;
+
         m_pending.buffer = fromResource<Buffer>(buffer);
-        m_pending.commitSpecific.attachOffset = offset;
         m_pending.commitSpecific.attached = true;
 
         emit attach(buffer, offset);
@@ -143,6 +145,13 @@ void Surface::surface_frame(Resource *resource, uint32_t callback)
     }
 }
 
+void Surface::surface_offset(Resource *resource, int32_t x, int32_t y)
+{
+    Q_UNUSED(resource);
+    QPoint offset(x, y);
+    m_pending.commitSpecific.attachOffset = offset;
+}
+
 bool WlCompositor::isClean() {
     for (auto *surface : std::as_const(m_surfaces)) {
         if (!CursorRole::fromSurface(surface)) {
